---
title: "Plato, Parmenides, and the Theory of Forms - Part 1"
date: 2018-07-23T22:03:31Z
tags: ["plato","parmenides","eidos","forms","idealism"]
topics: ["philosophy"]
image: /img/form-blocks.jpg
draft: false
---

It has become a commonplace habit in contemporary quasi-philosophical circles, to roll one’s eyes and snicker, or to sneer and sniff, whenever the mention of Plato’s Forms happens to sour the air. It seems to be taken for granted these days, that the Forms “just aren’t done” anymore, that somehow they’ve been shown to be disreputable or false, and that no one need any longer to take the idea seriously (least of all, professional philosophers). Yet, at the same time, one habit I have acquired during the last four years of intensive study of philosophy as a genuine student, is the reflex of taking people’s ideas seriously — and, for all the dismissals, nobody has ever bothered to explain to me *why* the Forms are no longer taken seriously, or *how* they’ve been shown to be disreputable.

Over the next three posts, I will be outlining the theory of Forms, beginning today with why Plato might have concocted the theory in the first place, moving next to what exactly the theory is and how it works, and finishing up with an analysis of the criticisms of the Forms offered by Parmenides (primarily), and a few others since. The point of these posts is to answer for myself the why and how questions nobody else is either willing or able to give me. That process has to begin with the reflex I just mentioned. In order to be confident of why I ought to either accept or reject this theory, I need to understand the theory, and to understand it, I need to portray it to myself, as closely as possible as Plato would have portrayed it to himself. Along the way, I hope others find these posts useful as well. On to today’s topic:

### Why Forms?

> We may give [the presocratics] credit for having built on the solid fact that all physics, if not all science, has a mathematical basis… ~G.M.A. Grube, Plato’s Thought
>
> When Forms are what they are in relation to one another, their essence is determined by the relation among themselves, and has nothing to do with resemblances… ~Plato, Parmenides

Socrates seemed to have been engaged in a project very similar to that of the presocratics. His theory of Forms[^1] (if we can rightly attribute it to him, and not just Plato) seems to be an attempt to do in the qualitative sense, what the Pythagoreans had done in the quantitative sense. By positing a theory of Forms for qualities such as “Likeness”, or “Beauty”, or “Greatness”, or “Justice”, Socrates seemingly hoped he could show the ultimate intelligibility of every facet of experiential reality, to be just as absolute and true as the sum of a series of numbers, or the square of the hypotenuse. “Ideas are what they are in relation to one another”, Parmenides echoes back to Socrates in his eponymous dialogue, in the same way that numbers are what they are in relation to one another. If that is so, and we can use numbers to say certainly true and useful things about the contents of the material world, then surely the same is possible for the Forms in relation to the experiential world. Aristotle appears to be partially confirming this hunch, in his Metaphysics:

> …Socrates, disregarding the physical universe and confining his study to moral questions, sought in this sphere for the universal… Plato followed him and assumed that the problem of definition is concerned not with any sensible thing but with entities of another kind; for the reason that there can be no general definition of sensible things which are always changing. These entities he called “Forms,” and held that all sensible things are named after them sensible and in virtue of their relation to them; whereas the Pythagoreans say that things exist by imitation of numbers, Plato says that they exist by participation… As to what this “participation” or “imitation” may be, they left this an open question… Further, he states that besides sensible things and the Forms there exists an intermediate class, the objects of mathematics, which differ from sensible things in being eternal and immutable, and from the Forms in that there are many similar objects of mathematics, whereas each Form is itself unique.[^2]

If Aristotle is correct, then the Forms and the objects of mathematics are not simply categorical siblings. Instead, there is a hierarchical order of inheritance in which the Forms are primary because they are templates of unity, and the objects of mathematics are templates of plurality, but mathematical objects include the properties of eternality and immutability of the Forms, because they are similarly independent of material reality.

This will be interesting to return to, later, when looking at Parmenides’ critique of the Forms. But, returning to Socrates’ (and Plato’s) motivations, the fundamental conundrum facing Socrates was this: His *method of definition* was forcing him into a dilemma. If definition is knowledge, and definition is not possible in an ever mutable Heraclitean reality, then knowledge of the world was not possible and the skeptical sophists turn out to be tragically correct. We cannot know anything. If, however, there is an intelligible reality of absolute truths about sensible reality, from which we can derive analytical definitions for qualitative experiences — in the same way we can derive analytical definitions for quantitative phenomena through the “imitation of numbers” exhibited by objects — then knowledge is possible, the sophists are thankfully wrong, and there are things we can say with certainty that we do indeed know. This should sound eerily familiar to anyone who’s read any Descartes. Seventeen hundred years later, he was still struggling with the same problem, but that’s a topic for another day.

According to Grube, one third century commentator is purported to have credited Aristotle with five distinct arguments supporting the necessity of the Forms. The first argument seems to implicitly acknowledge Parmenides’ final objection to Socrates (to which we’ll return, later), and — if I’m not being too optimistic — seems to also implicitly partially affirm my intuition above:

> The argument[s] from the sciences:… (i) if every science fulfils its function by having some one thing as its object, there must be such a single thing which is the object of that science, it must be unchanging and eternal, an eternal model beyond the particular sensible things, for these cannot be the objects of knowledge in the proper sense. The particular things or incidents in the physical world happen according to this model. This model is the Form. (ii) The objects of science exist. But science is concerned with something beyond the particulars which are infinite in number and indeterminate, while science is determined. There are therefore certain things beyond the particulars, and these are the Forms. (iii) Medicine is not the study of my health or yours, but of health as such. So the objects of geometry are not this or that equal or commensurate object, but equality and commensurability as such. These must exist, and are the Forms. These three ways of stating the case all come to this: knowledge and science exist; they cannot be the particular things we know since these are in a perpetual state of change whereas the objects of science must be constant; there must therefore be eternal and immutable realities, which we call the Forms. The best illustration is that of the mathematical sciences…[^3]

So, there does seem to be an association between the analytical truths of mathematics and the theorized analytical truths of experience, that the Forms could provide. There is a debate within the field of ancient philosophy over whether Plato was trying to reconcile two categories of knowledge (analytical and synthetic), or instead trying to establish the supremacy of a mind-dependent reality over all the sciences[^4]. The resolution of this debate one way or the other is less important to me, than that it exists at all. Because it shows that the scholars themselves are also aware of the fundamental problem Plato was grappling with, as I’ve outlined it here, and are simply quibbling over the precise shape of that problem. For my part, at the moment, I’m tending toward J. N. Findlay’s view from his book, “Plato: The Written and Unwritten Doctrines”. This is partly because of the quote from the Metaphysics above, and partly because I see Plato representing the “Transcendence” half of the larger “Transcendence vs Immanence” debate that took place between him and Aristotle. But that, too, is a much larger discussion for another day.

**Next Up: What are Forms, again?**

[^1]: I am using “Forms” (capitalized) uniformly throughout, to signify both “ἰδέα”, and “εἶδος”. I realize there’s a subtle distinction between these two terms, but that’s an issue of scholarship that is beyond the scope of this post. What’s more, neither term precisely means “idea” in the sense that we now use that word, to mean a nonce entity housed entirely in the mind, often synonymously called a “concept” or a “picture”. The Parmenides would make little sense in several passages, if that was the meaning we took for “Form”. 
[^2]: Metaphysics I, 987a-b (https://bit.ly/2LdTI05)
[^3]: Grube, G. M. A., Plato’s Thought, pg. 5 (1980, Hackett) – Grube is paraphrasing an author by the name of “Robin”, but he provides no bibliographical record for the citation. So, I am unable to track down this author to confirm this paraphrasing. Since this book was published originally in 1935, I am guessing “Robin” is someone who was a common reference of the period, but has since fallen out of fashion.
[^4]: See J.N. Findlay’s “Plato: The Written and Unwritten Doctrines”, for example. 
